polib._MOFileParser

Module polib :: Class _MOFileParser |
[hide private]
[frames] | no frames]

# Class _MOFileParser

source code
A class to parse binary mo files.

Instance Methods | [hide private]
__init__(self, fpath) _MOFileParser constructor. | source code
parse_magicnumber(self) Parse the magic number and raise an exception if not valid. | source code
parse(self) Build the instance with the file handle provided in the constructor. | source code
_readbinary(self, fmt=`'``c``'`) Private method that unpack n bytes of data using format <fmt>. | source code

Method Details | [hide private]

### _readbinary(self, fmt=`'``c``'`) | source code
Private method that unpack n bytes of data using format <fmt>. It returns a tuple or a mixed value if the tuple length is 1.